@@ -77,16 +77,8 @@ text_match <- function(x, terms, filter = NULL, ...)
 }
 
 
-text_locate <- function(x, terms, filter = NULL, random = FALSE, ...)
+text_locate <- function(x, terms, filter = NULL, ...)
 {
-    if (!missing(random)) {
-        warning("argument 'random' is deprecated; use the 'text_sample' function instead.",
-                call. = FALSE)
-        if (random) {
-            return(text_sample(x, terms, filter = filter, ...))
-        }
-    }
-
     with_rethrow({
         x <- as_corpus_text(x, filter, ...)
         terms <- as_character_vector("terms", terms)
@@ -106,7 +98,7 @@ text_sample <- function(x, terms, size = NULL, filter = NULL, ...)
         size <- as_nonnegative("size", size)
     })
 
-    loc <- text_locate(x, terms, filter,, ...)
+    loc <- text_locate(x, terms, filter, ...)
     nloc <- nrow(loc)
     if (is.null(size)) {
         size <- nloc
