@@ -53,8 +53,8 @@ static const R_CallMethodDef CallEntries[] = {
 	CALLDEF(stopwords, 1),
 	CALLDEF(subscript_json, 2),
 	CALLDEF(subset_json, 3),
-	CALLDEF(term_counts_text, 8),
-	CALLDEF(term_matrix_text, 5),
+	CALLDEF(term_stats, 7),
+	CALLDEF(term_matrix, 4),
 	CALLDEF(text_c, 3),
 	CALLDEF(text_count, 2),
 	CALLDEF(text_detect, 2),
