@@ -22,7 +22,7 @@ test_that("'text_tokens' normalizes tokens by default", {
     toks <- text_tokens(text)
 
     expect_equal(toks, list(
-        c("the", "quick", "(", "\"", "brown", "\"", ")", "fox", "can't",
+        c("the", "quick", "(", "\u201c", "brown", "\u201d", ")", "fox", "can't",
           "jump", "32.3", "feet", ",", "right", "?")))
 })
 
@@ -76,7 +76,7 @@ test_that("'text_tokens' can drop punctuation", {
     x <- "easy as 1, 2, 3!"
     f <- text_filter(drop_punct = TRUE)
     expect_equal(text_tokens(x, f),
-                 list(c("easy", "as", "1", NA, "2", NA, "3", NA)))
+                 list(c("easy", "as", "1", "2", "3")))
 })
 
 
@@ -84,7 +84,7 @@ test_that("'text_tokens' can drop numbers", {
     x <- "easy as 1, 2, 3!"
     f <- text_filter(drop_number = TRUE)
     expect_equal(text_tokens(x, f),
-                 list(c("easy", "as", NA, ",", NA, ",", NA, "!")))
+                 list(c("easy", "as", ",", ",", "!")))
 })
 
 
@@ -92,7 +92,7 @@ test_that("'text_tokens' can drop letter words", {
     x <- "easy as 1, 2, 3!"
     f <- text_filter(drop_letter = TRUE)
     expect_equal(text_tokens(x, f),
-                 list(c(NA, NA, "1", ",", "2", ",", "3", "!")))
+                 list(c("1", ",", "2", ",", "3", "!")))
 })
 
 
@@ -101,9 +101,8 @@ test_that("'text_tokens' can drop tokens", {
            "A man, a plan, a canal: Panama.")
     f <- text_filter(drop = stopwords_en)
     expect_equal(text_tokens(x, f),
-                 list(c("able", NA, NA, "ere", NA, "saw", "elba", "."),
-                      c(NA, "man", ",", NA, "plan", ",", NA, "canal", ":",
-                        "panama", ".")))
+                 list(c("able", "ere", "saw", "elba", "."),
+                      c("man", ",", "plan", ",", "canal", ":", "panama", ".")))
 })
 
 
@@ -111,7 +110,7 @@ test_that("'text_tokens' can make drop exceptions", {
     x <- "0, 1, 2, 3, 4, 5"
     f <- text_filter(drop_number = TRUE, drop_except = c("0", "2", "4"))
     expect_equal(text_tokens(x, f),
-                 list(c("0", ",", NA, ",", "2", ",", NA, ",", "4", ",", NA)))
+                 list(c("0", ",", ",", "2", ",", ",", "4", ",")))
 })
 
 
@@ -120,8 +119,8 @@ test_that("'text_tokens' can combine two words", {
            "a new York Street restaurant")
     f <- text_filter(combine = "new york")
     expect_equal(text_tokens(x, f),
-                 list(c("new york", "is", "the", "empire", "state"),
-                      c("a", "new york", "street", "restaurant")))
+                 list(c("new_york", "is", "the", "empire", "state"),
+                      c("a", "new_york", "street", "restaurant")))
 })
 
 
@@ -129,7 +128,7 @@ test_that("'text_tokens' can combine three words", {
     x <- c("New York City is the Big Apple")
     f <- text_filter(combine = "new york city")
     expect_equal(text_tokens(x, f),
-                 list(c("new york city", "is", "the", "big", "apple")))
+                 list(c("new_york_city", "is", "the", "big", "apple")))
 })
 
 
@@ -137,5 +136,14 @@ test_that("'text_tokens' combines the longest match", {
     x <- "I live in New York City, New York"
     f <- text_filter(combine = c("new york", "new york city"))
     expect_equal(text_tokens(x, f),
-                 list(c("i", "live", "in", "new york city", ",", "new york")))
+                 list(c("i", "live", "in", "new_york_city", ",", "new_york")))
+})
+
+
+test_that("'text_tokens' can use other connectors", {
+    x <- "I live in New York City, New York"
+    f <- text_filter(combine = c("new york", "new york city"),
+                     connector = "+")
+    expect_equal(text_tokens(x, f),
+                 list(c("i", "live", "in", "new+york+city", ",", "new+york")))
 })
