@@ -10,7 +10,7 @@ test_that("'as_utf8' errors on latin1 declared to be UTF-8", {
 
 
 test_that("utf8_valid errors on invalid UTF-8", {
-    x <- c("a", "b", "c", "d", intToUtf8(0x00200000))
+    x <- c("a", "b", "c", "d", "\xf8\x88\x80\x80\x80") # intToUtf8(0x00200000)
     Encoding(x) <- "UTF-8"
 
     expect_equal(utf8_valid(x), c(TRUE, TRUE, TRUE, TRUE, FALSE))
@@ -37,7 +37,7 @@ test_that("utf8_valid passes on valid ASCII in unknown encoding", {
 
 
 test_that("utf8_valid errors on invalid UTF8 in bytes encoding", {
-    x <- paste0("hello", intToUtf8(0xfffffff))
+    x <- paste0("hello", "\xfc\x8f\xbf\xbf\xbf\xbf") # intToUtf8(0xfffffff)
     Encoding(x) <- "bytes"
     expect_equal(utf8_valid(x), FALSE)
     expect_error(as_utf8(x), "argument entry 1 cannot be converted from \"bytes\" to \"UTF-8\"; it contains an invalid byte in position 6 (\\xfc)", fixed = TRUE)
